<?php
ini_set("mbstring.func_overload", "7");

require_once("classes/translator.class.php");
tl::register("reporting", dirname(__FILE__)."/lang");

require_once("include_main.php");
require_once("postgresql.php");

$cdrCall = false;

function inno_escape($str, $forQuery = true) {
    $str = str_replace(array("/", "}", "{", ","), array("//", "/}", "/{", "/,"), $str);
    return $str;
}

function set_header_error($err) {
    header("Content-type: text/xml");
    header("HTTP/1.1 500 Server error");
    $reply = "<error>".xmlentities($err)."</error>";
    header("Content-Length: ".strlen($reply));  
    echo $reply;            
}

$reportingDb = null;
function get_reporting_db() {
    global $reportingDb;
    if ($reportingDb == null) {
        $reportingDb = new DbPGSql("innovaphone-reporting", "innovaphone-reporting", "", "report.php");
        if (!$reportingDb->isOpen) {
            home_die(tl::tl("No postgresql db available."), "report.php");
            exit;
        }
    }
    return $reportingDb;
}

function close_reporting_db() {
    global $reportingDb;
    if($reportingDb) {
        $reportingDb->close();
        $reportingDb = null;
    }
}

class ReportingPbxObjectField extends InputPageAutoCompleteStringField
{
    public function getOptions($term) {
        $options = array();
        $pbx = InputPage::formInput("pbx");
        $result = self::getUsers("%$term%", $pbx);
        while(($row = pg_fetch_object($result))) {
            if(array_search($row->cn, $options) === false) {
                $options[] = $row->cn;
            }
        }
        return $options;
    }
    
    static function getUsers($term, $pbx) {
        global $reportingSession;
        $reportingDb = get_reporting_db();
        $query = "SELECT DISTINCT id, cn, sys, email
                    FROM cdr_users 
                    WHERE cn ILIKE '%".pg_escape_string($term)."%' 
                        AND {$reportingSession->reportingCfg->pbx->identifier}='".pg_escape_string($pbx)."'
                    ORDER BY cn ASC, id DESC";
        return $reportingDb->run($query);
    }
}

abstract class ReportingInputPage extends MainInnovaphonePage 
{
    const valFrom = "from", valTo = "to", valObject = "pbxobject", valSortBy = "sortby",
        valSortOrder = "sortorder", valGroupBy = "groupby", valFormat = "format",
        valList = "reportfilters", valBtnName = "buttoncreatereport", valHideDigits = "hidedigits",
        valBillingCalls = "billing", valMailName = "mail", valFilterInfo = "filterinfo", valDisplayedDuration = "displayedduration",
        valAnonym = "anonym", valPbx = "pbx", valBulk = "bulk", valConfId = "confid", valSender = "sender",
        valRecorderPath = "path";
    
    public function ReportingInputPage($site, $name, $printMenu = true) {
        $this->enableTranslations = true;
        parent::MainInnovaphonePage($site, $name, $printMenu);
        $this->logoImg = "/apps/innovaphone-reporting/images/logo_reporting.png";
        // add java script file
        $userPath = "/";
        if(ReportingMethods::isUserPath()) {
            $userPath = ReportingMethods::userPath;
        }
        $this->scriptfiles += array("java" => "/apps/innovaphone-reporting{$userPath}java.js");
        
        $this->links[count($this->links)] = array("rel" => "stylesheet", "type" => "text/css", "href" => "/apps/innovaphone-reporting{$userPath}style_reporting.css");        
        
        // default pageno if not set (1)
        if (($this->pageNo = $this->page()) == "") $this->pageNo = 1;        
        $version = 0;
        $hotfix = 0;
        MainInputPage::getVersions(Config::webRoot, $version, $hotfix);
        global $reportingSession;
        $app = $reportingSession->mainSession->getApp("innovaphone-reporting");
        if((int)$app->hotfix < (int)$hotfix) {
            die(tl::tlx('Install innovaphone-reporting hotfix{$arg[1]} first!', $hotfix));
            exit;
        }
        $this->searchArea = "<br><br><b>{$app->versionStr}</b>";
    }
    
    function getLoginAreaTd() {
        global $reportingSession;
        $ret = "";
        if($reportingSession->isUser()) {
            $ret .= $reportingSession->user->name;
            $ret .= "&nbsp;&nbsp;<a href='logout.php'>".tl::tl("Logout")."</a>";
        }
        return $ret;
    }
    
    function addMenu() {
        global $reportingSession;
        $this->addMainMenuItem(tl::tl("Reports"), "report.php", $this->name == "reportingreport");
        $this->addMainMenuItem(tl::tl("Config"), "config_reporting.php", $this->name == "reportingconfig");
        if(!$reportingSession->isUser()) {
            $this->addMainMenuItem(tl::tl("Diagnostics"), "diagnostics.php", $this->name == "innovaphonediagnostics");
        }
    }    
    
    function getHelpLink() {
        return Config::wikiHelpReporting.$this->pages[$this->pageNo]->getHelpAnchor();
    }
    
    function addFieldHideDigit(MyPage &$page, $default = "") {
        $hideDigit = $page->addField(new InputPageDigitStringField(self::valHideDigits, tl::tl("Hide last X digits"), $default));
        $hideDigit->emptyOk = true;
        $hideDigit->fullline = true;
        $hideDigit->attributes["size"] = "6px";
        $hideDigit->setHint(tl::tl("The last X digits of external numbers (depending on your LDAP configuration) will be replaced with *."));
        return $hideDigit;
    }
    
    function addFieldAnonym(MyPage &$page, $default = false) {
        $anonym = $page->addField(new InputPageCheckboxField(self::valAnonym, tl::tl("Anonym")));
        $anonym->fullline = true;
        $anonym->setHint(tl::tl("Check to anonymize all internal numbers/names."));
        $anonym->default["on"] = $default;
        return $anonym;
    }
    
    function addFieldDisplayedDuration(MyPage &$page, $default = ReportingConfigConsts::colCallDuration) {
        $colNames = ReportingConfigConsts::getColNames(true);
        $durations = array(ReportingConfigConsts::colCallDuration => $colNames[ReportingConfigConsts::colCallDuration],
                           ReportingConfigConsts::colBillingDuration => $colNames[ReportingConfigConsts::colBillingDuration],
                           ReportingConfigConsts::colConnDuration => $colNames[ReportingConfigConsts::colConnDuration]);
        $page->addField($dispDuration = new InputPageDropdownField(ReportingInputPage::valDisplayedDuration, tl::tl("Displayed Duration"), $durations));
        $dispDuration->default[$default] = true;
        return $dispDuration;
    }
    
    function addFieldGroupBy(MyPage &$page, $default = "")
    {
        $colNames = ReportingConfigConsts::getColNames(true);
        
        $groupBys = array("" => "",
            ReportingConfigConsts::colLocalTime => tl::tl("Date"),
            ReportingConfigConsts::colCCnUser => $colNames[ReportingConfigConsts::colCCnUser]);
        $groupBy = $page->addField(new InputPageDropdownField(self::valGroupBy, tl::tl("Group by"), $groupBys));
        $groupBy->default[$default] = true;
        $groupBy->fullline = true;
        return $groupBy;
    }

    function addFieldSortBy(MyPage &$page, $default = "")
    {
        $sortBys = array("" => "",
            ReportingConfigConsts::colLocalTime => tl::tl("Time"),
            ReportingConfigConsts::colCCnUser => tl::tl("Object"),
            ReportingConfigConsts::colCallDuration => tl::tl("Duration"),
            ReportingConfigConsts::colAlertDuration => tl::tl("Alert Duration"));
        $sortBy = $page->addField(new InputPageDropdownField(self::valSortBy, tl::tl("Sort by"), $sortBys));
        $sortBy->default[$default] = true;
        $sortBy->fullline = true;
        return $sortBy;
    }

    function addFieldCheckBoxSortOrder(MyPage &$page, $default = "")
    {
        $sortOrder = $page->addField(new InputPageCheckBoxField(self::valSortOrder, tl::tl("Sort ascending")));
        $val = InputPage::formInput(self::valObject);
        if($default == "ASC" && !isset($val)) {
            $sortOrder->default["on"] = true;
        }
        $sortOrder->fullline = true;

        return $sortOrder;
    }
    
    private function getPbxOptions(&$firstOption) {
        $reportingDb = get_reporting_db();
        /* @var $reportingSession ReportingSession */ global $reportingSession;
        $cond = "";
        if($reportingSession->isUser()) {
            $query = "SELECT DISTINCT fc.value FROM filter_conditions fc
                        WHERE fc.type='".FilterCondition::typePbx."' 
                                AND fc.name='cu.{$reportingSession->reportingCfg->pbx->identifier}'
                                AND fc.filter_id IN (SELECT uf.filter_id 
                                                FROM user_filters uf 
                                                JOIN filters f ON uf.filter_id=f.id
                                                WHERE uf.user_id={$reportingSession->user->id} AND f.base_filter IS NULL)
                                AND fc.value!='' AND fc.value IS NOT NULL";
            $result = $reportingDb->run($query);
            if(pg_num_rows($result) > 0) {
                $cond = "WHERE (";
                while(($row = pg_fetch_object($result))) {
                    if($row->value == '%') {    // this is a base filter, which allows access to all PBXes
                        $cond = "";
                        break;
                    }
                    $cond .= "cu.{$reportingSession->reportingCfg->pbx->identifier} ILIKE '".pg_escape_string($reportingDb->db, $row->value)."' OR ";
                }
                if($cond != "") {
                    $cond = rtrim($cond, " OR ");
                    $cond .= ")";
                }
            }
        }
        $options = array();
        $query = "SELECT DISTINCT cu.".$reportingSession->reportingCfg->pbx->identifier." AS name 
                    FROM cdr_users cu
                    $cond
                    ORDER BY ".$reportingSession->reportingCfg->pbx->identifier;
        $result = $reportingDb->run($query);
        while(($row = pg_fetch_object($result))) {
            $options[$row->name] = $row->name;
        }
        if(!count($options)) $options[''] = '';
        foreach($options as $option) {
            $firstOption = $option;
            break;
        }
        return $options;
    }

    function addObjectAndFilterList(MyPage &$page, $defaultPbxObject = "%", $addPbxObject = true, $addFilterList = true) 
    {
        $pbxObject = null;
        if($addPbxObject) {
            $firstOption = "";
            $options = $this->getPbxOptions($firstOption);
            
            $page->addField($pbx = new InputPageDropdownField(self::valPbx, tl::tl("PBX"), $options));
            $pbx->fullline = true;
            $pbx->default[$firstOption] = true;
            
            $pbxObject = $page->addField(new ReportingPbxObjectField(self::valObject, tl::tl("Object (Long Name)"), $defaultPbxObject));
            $pbxObject->autoFocus = true;
            $pbxObject->delay = 100;
            $pbxObject->emptyOk = true;
            $pbxObject->tdattributes["valign"] = "top";
            // pbx value must be known inside ReportingPbxObjectField getOptions, as the CN is not unique anymore
            $java = "changePbx('{$pbx->name}', '".self::valObject."', '".$pbxObject->getUrl()."', {$pbxObject->autoFocus}, {$pbxObject->delay});";
            $pbx->attributes["onChange"] = "javascript:$java";
            $pbx->setJavaScriptInit("function JavaScriptInit_{$pbx->name}() { $java }");
        }
        if($addFilterList) {
            $text = ($addPbxObject ? tl::tl("or Filter(s)") : tl::tl("Base Filter(s)"));
            $listText = $page->addField(new InputPageText("filtertext", $text));
            $listText->tdattributes["valign"] = "top";

            $list = $page->addField(new MainInputPageListField(self::valList));
            $list->sortDirection = InputPageListField::sortIgnore;
            $list->ignoreHead = true;
            $list->removableRows = true;
            //$list->tdattributes["valign"] = "top";
            $list->oddAttributes["class"] = "filter-listfield-tr-separator";
            $list->evenAttributes["class"] = "filter-listfield-tr-separator";
            $list->headAttributes["class"] = "filter-headlist-separator";
            $list->divattributes["class"] = "filter-listfield";
            $list->addColumn($listFilters = new InputPageDropdownField($list->name."select", null, array()), null /* tl::tl("Filter")*/);
            $listFilters->sortType = genericInputPageItem::sortIgnore;
        }
        return $pbxObject;
    }
    
    static function getFilterListArray($excludeUserFilters = false, $userId = 0, $addNullFilter = false)
    {
        $conds = "1=1";
        if($excludeUserFilters) {
            $conds .= " AND f.base_filter IS NULL";
        }
        if($userId != 0) {
            $conds .= " AND f.id IN (SELECT uf.filter_id 
                                        FROM user_filters uf
                                        WHERE uf.user_id=$userId)";
        }
        $reportingDb = get_reporting_db();
        $query = "SELECT f.id, f.name 
                    FROM filters f
                    WHERE $conds
                    ORDER BY lower(f.name)";
        $result = $reportingDb->run($query);
        $selects = array();
        if((!$excludeUserFilters && $userId == 0) || $addNullFilter) {
            $selects = array(0 => "");
        }
        while($row = pg_fetch_object($result)) {
            $selects[$row->id] = $row->name;
        }
        return $selects;
    }
}

class ReportingMailsField extends InputPageStringField
{
    function valid()
    {
        $mails = explode(",", $this->value);
        foreach($mails as $mail) {
            if(!InputPageMailField::checkMail($mail, $this->msg)) {
                return false;
            }
        }
        return true;
    }
}

class ReportingHourMinutesField extends InputPageStringField
{
    function ReportingHourMinutesField($name, $prompt = "", $default = "", InputPageAction $button = null) {
        parent::__construct($name, $prompt, $default, $button);
        $this->hint = tl::tl("Format 00:00 (max 23:59)");
        $this->attributes["size"] = "4";
    }
    
    function valid()
    {
        if(!preg_match("/^(([0-1]{1}[0-9]{1})|(2[0-3]{1})):[0-5]{1}[0-9]{1}$/", $this->value)) {
            $this->msg = tl::tl("The time must be given in format 00:00 (max 23:59).");
            return false;
        }
        return true;
    }
}

// digit string (no sign)
class ReportingDigitStringField extends InputPageDigitstringField {
    public function __construct($name, $prompt = "", $default = "", InputPageAction $button = null) {
        parent::__construct($name, $prompt, $default, $button);
        $this->type = "";
    }
}

class ReportingMethods 
{
    const pwSalt = "4aBz";
    const userPath = "/user/";
    
    static function isUserPath() {
        if(stripos($_SERVER['SCRIPT_FILENAME'], self::userPath) !== false) {
            return true;
        }
        return false;
    }
    
    // retrieve account data from myinno.user, function expects md5 password
    static function checkAccount($name, $pw, $checkCol = "cookie") {
        $reportingDb = get_reporting_db();
        $query = "SELECT *
                    FROM users
                    WHERE name='". pg_escape_string($name) ."' AND $checkCol='$pw'";
        if($checkCol == "cookie") {
            $query .= " AND $checkCol IS NOT NULL AND $checkCol != ''";
        }
        $result = $reportingDb->run($query);
        return $result;
    }
    
    static function getMd5Pw($name, $pw) {
        return md5(strtolower($name).self::pwSalt.$pw);
    }
    
    static function getUser($id = 0) {
        $reportingDb = get_reporting_db();
        $query = "SELECT * FROM users";
        if($id > 0) {
            $query .= " WHERE id=$id";
        }
        $query .= " ORDER BY name";
        $result = $reportingDb->run($query);
        $users = array();
        while($row = pg_fetch_object($result)) {
            $reportingUser = self::getUserFromRow($row);
            if($id > 0) {
                return $reportingUser;
            }
            else {
                $users[$reportingUser->id] = $reportingUser;
            }
        }
        if($id > 0) {
            return null;
        }
        else {
            return $users;
        }
    }
    
    static function getUserFromRow(&$row) {
        $reportingUser = new ReportingUser();
        $reportingUser->id = $row->id;
        $reportingUser->password = $row->password;
        $reportingUser->name = $row->name;
        $reportingUser->filters = ReportingInputPage::getFilterListArray(true, $row->id);
        return $reportingUser;
    }
    
    static function getFilter($id, $name = "", &$error) {
        $reportingDb = get_reporting_db();
        $cond = "";
        if($name != "") {
            $cond = "name ILIKE '".pg_escape_string($name)."'";
        }
        else {
            $cond = "id=$id";
        }
        $query = "SELECT * FROM filters WHERE $cond";
        $result = $reportingDb->run($query);
        $filter = new Filter();
        if(!($row = pg_fetch_object($result))) {
            $error = tl::tl("This filter does not exist anymore.");
            return null;
        }
        $filter->id = $row->id;
        $id = $filter->id;  // set $id, if filter is retrieved by $name
        $filter->name = $row->name;
        $filter->callDirection = $row->call_direction;
        $filter->callingDuration = $row->calling_duration;
        $filter->callingDurationCompare = $row->calling_duration_compare;
        $filter->alertDuration = $row->alert_duration;
        $filter->alertDurationCompare = $row->alert_duration_compare;
        $filter->callingState = $row->calling_state;
        $filter->callType = $row->call_type;
        $filter->desc = $row->description;
        $filter->logo = $row->logo;
        $filter->footer = $row->footer;
        $filter->baseFilter = (isset($row->base_filter) ? $row->base_filter : 0);
        $filter->anonym = ($row->anonym == "t" ? true : false);
        
        $query = "SELECT * FROM filter_conditions WHERE filter_id=$id ORDER BY type";
        $result = $reportingDb->run($query);
        while($row = pg_fetch_object($result)) {
            $filter->conds[] = new FilterCondition($row->name, $row->value, $row->type);
        }
        $query = "SELECT * FROM filter_times WHERE filter_id=$id ORDER BY time_from";
        $result = $reportingDb->run($query);
        while($row = pg_fetch_object($result)) {
            $filterTime = new FilterTime();
            $filterTime->setTime($row->time_from, $row->time_to);
            $filterTime->day = $row->time_day;
            $filter->times[] = $filterTime;
        }
        $filter->columns = ReportingXmlCfg::getFilterColumns();
        return $filter;
    }    
    
    static function checkUserFilter($filterId) {
        global $reportingSession;
        if($filterId == 0) return true;
        if(!$reportingSession->isUser()) return true;
        $reportingDb = get_reporting_db();
        $query = "SELECT f.id FROM filters f 
                    JOIN user_filters uf ON (uf.filter_id=f.id)
                    WHERE f.id={$filterId} AND uf.user_id={$reportingSession->user->id} AND f.base_filter IS NOT NULL";
        $result = $reportingDb->run($query);
        return pg_num_rows($result) > 0;
    }
    
    static function getReportMail($id, $name = "", &$error) {
        $reportingDb = get_reporting_db();
        $cond = "";
        if($name != "") {
            $cond = "name ILIKE '".pg_escape_string($name)."'";
        }
        else {
            $cond = "id=$id";
        }
        $query = "SELECT * FROM mails WHERE $cond";
        $result = $reportingDb->run($query);
        $mail = new ReportMail();
        if(!($row = pg_fetch_object($result))) {
            $error = tl::tl("This report mail does not exist anymore.");
            return null;
        }
        $mail->id = $row->id;
        $id = $mail->id;  // set $id, if filter is retrieved by $name
        $mail->name = $row->name;
        $mail->dayOfMonth = $row->day_of_month;
        $mail->dayOfWeek = $row->day_of_week;
        $mail->format = $row->format;
        $mail->groupBy = $row->group_by;
        $mail->sortBy = $row->sort_by;
        $mail->sortOrder = $row->sort_order;
        $mail->hideDigits = intval($row->hide_digits);
        $mail->interval = $row->interval;
        $mail->mails = $row->mails;
        $mail->setTime($row->time);
        $mail->pbx = $row->pbx;
        $mail->pbxObject = $row->pbx_object;
        $mail->userId = $row->user_id;
        $mail->lang = ((isset($row->lang) && $row->lang != '') ? $row->lang : "en");
        $mail->compress = ($row->compress == "t" ? true : false);
        $mail->displayedDuration = $row->displayed_duration;
        $mail->anonym = ($row->anonym == "t" ? true : false);
        $mail->bulk = ((isset($row->bulk) && $row->bulk == "t") ? true : false);
        $mail->sender = $row->sender;
        if($mail->displayedDuration == "") {
            $mail->displayedDuration = ReportingConfigConsts::colCallDuration;
        }
        
        $query = "SELECT f.name AS name, f.id AS id FROM mail_filters mf
                    JOIN filters f ON mf.filter_id=f.id
                    WHERE mf.mail_id=$id";
        $result = $reportingDb->run($query);
        while($row = pg_fetch_object($result)) {
            $mail->filters[$row->id] = $row->name;
        }
        return $mail;
    }    
    
    static function getLdapServer($id, &$error) {
        $reportingDb = get_reporting_db();
        $query = "SELECT * FROM ldap_servers WHERE id=$id";
        $result = $reportingDb->run($query);
        $ldapServer = new LdapServer();
        if(!($row = pg_fetch_object($result))) {
            $error = tl::tl("This ldap server does not exist anymore.");
            return null;
        }
        $ldapServer->id = $row->id;
        $ldapServer->active = $row->active == 't';
        $ldapServer->ac = $row->ac;
        $ldapServer->base = $row->base;
        $ldapServer->filter = $row->filter;
        $ldapServer->cc = $row->cc;
        $ldapServer->el = $row->el;
        $ldapServer->host = $row->host;
        $ldapServer->ip = $row->ip;
        $ldapServer->nameAttrib = $row->name_attrib;
        $ldapServer->np = $row->np;
        $ldapServer->numberAttrib = $row->number_attrib;
        $ldapServer->password = rc4_decrypt(strrev($row->host), $row->password);
        $ldapServer->pbx = $row->pbx;
        $ldapServer->port = $row->port;
        $ldapServer->server = $row->server;
        $ldapServer->sn = $row->sn;
        $ldapServer->user = $row->username;
        return $ldapServer;
    }    
    
    static function cleanupDelCDRs(&$error, &$deleted) {
        $reportingDb = get_reporting_db();
        $query = "DELETE FROM del_cdrs WHERE time_deleted<(now() - INTERVAL '3 months')";
        if(($result = $reportingDb->run($query)) === false) {
            $error = pg_last_error($reportingDb->db);
            return false;
        }
        $deleted = pg_affected_rows($result);
        return true;
    }
    
    static function deleteCDRs($cond, &$error, &$cdrs) {
        $error = "";
        $cdrs = 0;
        $reportingDb = get_reporting_db();
        $delLimit = 5000;
        do {
            $query = "LOCK TABLE cdrs, events, groups, del_cdrs, cdr_properties IN EXCLUSIVE MODE";
            if($reportingDb->run("BEGIN") === false || $reportingDb->run($query) === false) {
                $error = pg_last_error($reportingDb->db);
                return false;
            }
            $query = "SELECT cdrs.id, cdrs.cdr_guid 
                        FROM cdrs 
                        JOIN cdr_users cu ON cdrs.cdr_user_id=cu.id
                        WHERE $cond LIMIT $delLimit";
            $result = $reportingDb->run($query);
            if(pg_num_rows($result) == 0) {
                $reportingDb->run("ROLLBACK");  // end started transaction
                break;
            }
            $insertDel = "INSERT INTO del_cdrs (cdr_guid) VALUES ";
            $ids = "";
            while(($row = pg_fetch_object($result))) {
                $insertDel .= "('{$row->cdr_guid}'),";
                $ids .= "{$row->id},";
            }
            $ids = rtrim($ids, ",");
            $insertDel = rtrim($insertDel, ",");
            $query1 = "DELETE FROM cdr_properties WHERE cdr_id IN ($ids)";
            $query2 = "DELETE FROM events WHERE cdr_id IN ($ids)";
            $query3 = "DELETE FROM groups WHERE cdr_id IN ($ids)";
            $query4 = "DELETE FROM cdrs WHERE id IN ($ids)";
            if($reportingDb->run($insertDel) === false || $reportingDb->run($query1) === false ||
                $reportingDb->run($query2) === false ||$reportingDb->run($query3) === false ||
                ($delResult = $reportingDb->run($query4)) === false || $reportingDb->run("COMMIT") === false) {
                $error = pg_last_error($reportingDb->db);
                $reportingDb->run("ROLLBACK");
                return false;
            }
            $cdrs += pg_affected_rows($delResult);
        } while(true);
        if($cdrs > 1000) {  // do full analyze and reindex
            $cmd = "/usr/bin/sudo /usr/local/bin/config.sh postgres vacuum-full innovaphone-reporting";
            MainMethods::callConfigSh($cmd, $retval);
        }
        return true;
    }
}

class ReportingReportConsts
{
    const pageReport = 1;
    const tabCalls = "calls";
    const modeCreateReport = "createreport";
}

class ReportingLoginConsts {
    const pageLogin = 1;
}

class ReportingConfigConsts
{
    const pageConfig = 1;
    const tabFilter = "filter", tabPgsql = "pgsql", tabReplication = "repl", tabLdap = "ldap", tabMail = "mail", tabImages = "images",
            tabUsers = "users", tabPbx = "pbx", tabVoicePlayer = "recording";
    const modeFilter = "createfilter", modeDeleteFilter = "deletefilter", modeLdap = "createldap", modeDeleteLdap = "deleteldap",
          modeMail = "createmail", modeDeleteMail = "deletemail",  modeImage = "createimage", modeDeleteImage = "deleteimage",
            modeUser = "createuser", modeDeleteUser = "deleteuser";
    
    const callingStateAlert = "alert", callingStateConn = "conn", callingStateAll = "all", callingStateBusy = "busy", callingStateNoChannel = "nochannel";
    const callingDurationSmaller = "<=", callingDurationGreater = ">=", callingDurationJustGreater = ">" ;
    const callDirectionIn = "to", callDirectionOut = "from", callDirectionAll = "all", callDirectionCf = "cf", callDirectionCt = "ct";
    const callTypeInt = "int", callTypeExt = "ext", callTypeAll = "all";
    const outFormatPdf = "pdf", outFormatXml = "xml", outFormatXsl = "xsl", outFormatCsv = "csv";
    const reportXslLimit = 10000;
    // names of columns are equal to their database equivalent
    // update the C Version below if necessary and report.xsl as well
    const colUnixTimeSort = "unix_time", colDateSort = "datum_sort";
    const colCH323 = "cdr_h323", colCdH323 = "ev_h323", colCLowerCn = "lower(cu.cn)", colCCnUser = "cu.cn",
        colCE164 = "cdr_e164", colCdE164 = "ev_e164", colCdDn = "ev_dn", 
        colCdCallbackE164 = "cdrp_callback_e164", colCdCallbackH323 = "cdrp_callback_h323", colCdCallbackDn = "cdrp_callback_dn", colCdCallbackTime = "cdrp_callback_time", 
        colCdCallbackTimeUnix = "date_part('epoch', cdrp_callback_time AT TIME ZONE 'UTC') AS unix_time_callback",
        colCallDuration = "call_duration", colAlertDuration = "alert_duration", colGroups = "cdrp_cdr_id_groups", colConf = "cdrp_conf",
        colConnDuration = "conn_duration", colBillingDuration = "billing_duration",
        colCallType = "cdrp_type",  colCallDirection = "cdr_dir", colCauseCode = "cause_code", colCallStatus = "status",
        colPhys = "cdr_phys", colSys = "cu.sys", colNode = "cdr_node", colPbxUser = "cu.pbx", 
        colCFlow = "cdrp_call_flow", colLocalTime = "local_stamp", colUtcUnixTime = "date_part('epoch', utc_stamp AT TIME ZONE 'UTC') AS utc_unix_time",
        colUnixTime = "date_part('epoch', local_stamp AT TIME ZONE 'UTC') AS unix_time", colCdrId = "cdr.id",
        colVoiceRecorderPath = "recorder_path",
        colLeft = "left", colRight = "right", colCallback = "callback"; // left/right are dummy columns and shouldn't be queried

    /*
     * C Version. Remember to add any new variable in pg_report.c/h if needed!
     */    
    
    // calls state codes
    const codeUnalloc = "1", codeNoRouteSpec = "2", codeNoRouteDest = "3", codeChUnacep = "6", 
        codeCallRej = "21", codeDestOutOrder = "27", codeInvNumberFormat = "28", codeIncompDest = "88", 
        codeNoCircChAv = "34", codeNetworkOutOrder = "38", codeReqNoCircChAv = "44", codeResourcesUnav = "47", 
        codeTempFailure = "41", codeOutCallsBarred = "52", codeServOptUnav = "63", codeNoBearerCapImp = "65", 
        codeRecOnTimerExp = "102", codeProtError = "111", codeInterworkUnspec = "127",
        codeNoUserResp = "18", codeNoRespFromUser = "19", 
        codeUserBusy = "17", codeNonSelUserClr = "26";
    // end of state calls

    static function getColNames($utc = false, $db = true) {
        $colNames = array(
            self::colCCnUser => tl::tl("Object"),
            self::colConf => tl::tl("Conference Id"),
            self::colCallDirection => tl::tl("Direction"),
            self::colCallType => tl::tl("Call Type"),
            self::colAlertDuration => tl::tl("Alert Duration"),
            self::colCFlow => tl::tl("Call Flow"),
            self::colCallDuration => tl::tl("Call Duration (Total)"),
            self::colBillingDuration => tl::tl("Billing Duration"),
            self::colConnDuration => tl::tl("Call Duration (User)"),
            self::colGroups => tl::tl("Groups"),
            self::colSys => tl::tl("System Name"),
            self::colNode => tl::tl("Node"),
            self::colPbxUser => tl::tl("PBX Name"),
            self::colPhys => "Phys",
            self::colCauseCode => tl::tl("Cause"),
            self::colCdrId => "CDR Id",
            self::colVoiceRecorderPath => "Voice Recorder Path");
        
        if($utc) {
            $colNames[self::colLocalTime] = tl::tl("Time");
        }
        if($db === false) {
            $colNames[self::colCallStatus] = tl::tl("Status");
            $colNames[self::colLeft] = tl::tl("Left");
            $colNames[self::colRight] = tl::tl("Right");
            $colNames[self::colCallback] = tl::tl("Callback");
        }
        //asort($colNames);
        return $colNames;  
    } 
    
    static function getCondColNames() {
        $colNames = self::getColNames();
        
        $colNames[self::colCCnUser] = tl::tl("Object");
        $colNames[self::colCdE164] = tl::tl("Number");
        $colNames[self::colCdH323] = tl::tl("Remote Name");
        $colNames[self::colCdDn] = tl::tl("Remote Display Name");
        $colNames[self::colCE164] = tl::tl("Number");
        $colNames[self::colCH323] = tl::tl("Local Name");
        
        return $colNames;  
    }

    static function getDefaultOrderCols($cflow = false) {
        $cols = self::getColNames(true);

        unset($cols[self::colCallType]);
        unset($cols[self::colAlertDuration]);
        unset($cols[self::colBillingDuration]);
        unset($cols[self::colCallDuration]);
        unset($cols[self::colGroups]);
        unset($cols[self::colSys]);
        unset($cols[self::colNode]);
        unset($cols[self::colPbxUser]);
        unset($cols[self::colPhys]);
        unset($cols[self::colCauseCode]);
        unset($cols[self::colCdrId]);
        if($cflow==false)
            unset($cols[self::colCFlow]);
        return $cols;
    }

    static function getColName($colName) {
        switch($colName) {
            case "obj": return self::colCCnUser;
            case "alert-duration": return self::colAlertDuration;
            case "conn-duration": return self::colConnDuration;
            case "billing-duration": return self::colBillingDuration;
            case "call-duration": return self::colCallDuration;
            case "dir": return self::colCallDirection;
            case "time": return self::colLocalTime;
            case "status": return "";
            default: return $colName;
        }
    }
    
    static function getColXmlNames() {
        $colNames = array();
        
        $colNames[self::colCCnUser] = "obj";
        $colNames[self::colConf] = "id";
        $colNames[self::colCFlow] = "flow";
        $colNames[self::colCallDirection] = "dir";
        $colNames[self::colCallStatus] = "status";
        $colNames[self::colCallType] = "type";
        $colNames[self::colAlertDuration] = "alert-duration";
        $colNames[self::colCallDuration] = "call-duration";
        $colNames[self::colConnDuration] = "conn-duration";
        $colNames[self::colBillingDuration] = "billing-duration";
        $colNames[self::colGroups] = "groups";
        $colNames[self::colSys] = "sys";
        $colNames[self::colNode] = "node";
        $colNames[self::colPbxUser] = "pbx";
        $colNames[self::colPhys] = "phys";
        $colNames[self::colCauseCode] = "cause";
        $colNames[self::colLocalTime] = "time";
        $colNames[self::colLeft] = "left";
        $colNames[self::colRight] = "right";
        $colNames[self::colCallback] = "callback";
        $colNames[self::colCdrId] = "cdr-id";
        $colNames[self::colVoiceRecorderPath] = "vr-path";
        return $colNames;  
    }
}

class FilterCondition {
    var $name;
    var $value;
    var $type;
    
    const typePbx = "pbx", typeRemote = "remote", typeLocal = "local";
    
    public function FilterCondition($name = "", $value = "", $type = "") {
        $this->name = $name;
        $this->value = $value;
        $this->type = $type;
    }
}

class FilterColumn {
    var $name;
    var $sortOrder;
    var $numDefs;

    public function FilterColumn($name, $sortOrder = 0, $numDefs = 0) {
        $this->name = $name;
        $this->sortOrder = $sortOrder;
        $this->numDefs = $numDefs;
    }
    
    public function equals($col) {
        if($this->name == $col->name && $this->sortOrder == $col->sortOrder) {
            return true;
        }
        return false;
    }
}

class FilterTime {
    const dayUnspecified = 0, daySunday = 1, dayMonday = 2, dayTuesday = 3, dayWednesday = 4, dayThursday = 5,
            dayFriday = 6, daySaturday = 7, dayMonFri = 8, daySaSo = 9;
    const format = "%02d:%02d";
    var $fromMinute = "00";
    var $fromHour = "00";
    var $toMinute = "00";
    var $toHour = "00";
    var $day = self::dayUnspecified;
    
    function setTime($from, $to) {
        $vals = explode(":", $from);
        $this->fromHour = $vals[0];
        $this->fromMinute = $vals[1];
        $vals = explode(":", $to);
        $this->toHour = $vals[0];
        $this->toMinute = $vals[1];
    }
    
    function getFrom() {
        return sprintf(self::format, $this->fromHour, $this->fromMinute);
    }
    
    function getTo() {
        return sprintf(self::format, $this->toHour, $this->toMinute);
    }
}

class Filter {
    var $callDirection = ReportingConfigConsts::callDirectionAll;
    var $callType = ReportingConfigConsts::callTypeAll;
    var $callingState = ReportingConfigConsts::callingStateAll;
    var $callingDuration = "";
    var $callingDurationCompare = ReportingConfigConsts::callingDurationGreater;
    var $alertDuration = "";
    var $alertDurationCompare = ReportingConfigConsts::callingDurationGreater;
    var $desc = "";    
    var $name = "";
    var $conds = array();
    var $columns = array();
    var $times = array();
    var $id = 0;
    var $logo = "";
    var $footer = "";
    var $baseFilter = 0;
    var $anonym = false;
}

class VoicePlayer {
    var $port = 0;
    
    public function __construct($port = 0) {
        $this->port = $port;
    }
}

class PbxConfig {
    const identifierPbx = "pbx", identifierSys = "sys";
    var $identifier;
    
    public function PbxConfig($identifier = self::identifierSys) {
        $this->identifier = $identifier;
    }
}

class Replication {
    const modeOff = "off", modeMaster = "master", modeStandby = "standby";
    var $mode;
    var $server;
    var $password;
    var $interval;
    
    public function Replication($mode = self::modeOff, $server = "", $password = "", $interval = 15) {
        $this->mode = $mode;
        $this->server = $server;
        $this->password = $password;
        $this->interval = $interval;
    }
}

class ReportMail {
    const intervalDaily = 0, intervalWeekly = 1, intervalMonthly = 2;
    var $id = 0;
    var $name = "";
    var $filters = array();
    var $pbx = "";
    var $pbxObject = "";
    var $groupBy = "";
    var $sortBy = "";
    var $sortOrder = "ASC";
    var $interval = self::intervalDaily;
    var $mails = "";
    var $format = ReportingConfigConsts::outFormatPdf;
    var $hideDigits = 0;
    var $timeMinute = 0;
    var $timeHour = 0;
    var $dayOfWeek = 0;
    var $dayOfMonth = 0;
    var $userId = 0;
    var $lang = "en";
    var $compress = true;
    var $displayedDuration = ReportingConfigConsts::colCallDuration;
    var $anonym = false;
    var $bulk = false;
    var $sender = "";
    
    function getTime() {
        return sprintf(FilterTime::format, $this->timeHour, $this->timeMinute);
    }
    
    function setTime($time) {
        $vals = explode(":", $time);
        $this->timeHour = $vals[0];
        $this->timeMinute = $vals[1];
    }
}

class LdapServer {
    var $id = 0;
    var $server = "";
    var $host = "";
    var $port = "389";
    var $password = "";
    var $user = "";
    var $base = "";
    var $filter = "";
    var $nameAttrib = "";
    var $numberAttrib = "";
    var $pbx = "";
    var $cc = "";
    var $ac = "";
    var $np = "";
    var $ip = "";
    var $el = "";
    var $sn = "";
    var $active = true;
}

class ReportingCleanup {
    var $active = false;
    var $months = 12;
    var $weeks = 0;
}

class ReportingXmlCfg {
    var $error = "";
    /**
     *
     * @var Replication
     */
    var $replication = null;
    /**
     *
     * @var PbxConfig
     */
    var $pbx = null;
    var $mtime = 0;
    
    /**
     *
     * @var ReportingCleanup
     */
    var $cleanup = null;
    
    /**
     *  @var VoicePlayer
     */
    var $voicePlayer = null;
    
    public function ReportingXmlCfg() {
        $this->readConfig();
    }
    
    public function readConfig($file = Config::reportingConfig, $import = false) {
        if(!$import) {
            $this->replication = new Replication();
            $this->pbx = new PbxConfig();
            $this->cleanup = new ReportingCleanup();
            $this->voicePlayer = new VoicePlayer();
        }
        $doc = new DOMDocument();
        $doc->encoding = "utf-8";
        $doc->preserveWhiteSpace = false;
        @$doc->load($file);
        if($doc !== false) {
            if(!$import && file_exists($file)) {
                $this->mtime = filemtime($file);
            }
            $config = $doc->getElementsByTagName ("config");
            if($config->length > 0) {
                $config = $config->item(0);
                foreach($config->childNodes as $node) {
                    switch($node->nodeName) {
                        case "voice-player":
                            foreach($node->childNodes as $child) {
                                switch($child->nodeName) {
                                    case "port":
                                        $this->voicePlayer->port = intval($child->textContent);
                                        break;
                                }
                            }
                            break;
                        case "cleanup":
                            foreach($node->attributes as $attrib) {
                                switch($attrib->name) {
                                    case "active":
                                        $this->cleanup->active = (($attrib->value == "true" || $attrib->value == "1") ? true : false);
                                        break;
                                    case "months":
                                        $this->cleanup->months = intval($attrib->value);
                                        break;
                                    case "weeks":
                                        $this->cleanup->weeks = intval($attrib->value);
                                        break;
                                }
                            }
                            break;
                        case "replication":
                            if($import) continue;
                            foreach($node->childNodes as $child) {
                                switch($child->nodeName) {
                                    case "mode": $this->replication->mode = $child->textContent; break;
                                    case "server": $this->replication->server = $child->textContent; break;
                                    case "password": $this->replication->password = $child->textContent; break;
                                    case "interval": $this->replication->interval = (int)$child->textContent; break;
                                }
                            }
                            $this->replication->password = rc4_decrypt(strrev($this->replication->server), $this->replication->password);
                            break;
                        case "pbx":
                            if($import) continue;
                            foreach($node->childNodes as $child) {
                                switch($child->nodeName) {
                                    case "identifier": $this->pbx->identifier = $child->textContent; break;
                                }
                            }
                            break;
                    }
                }
            }
            else {
                $this->error = tl::tlx('Config file {$arg[1]} does not contain a <config> tag.', $file);
                return false;
            }
        }
        else {
            $this->error = tl::tlx('Couldn\'t parse config file {$arg[1]}.', $file);
            return false;
        }
        return true;
    }
    
    public static function getFilterColumns() {
        $cols = ReportingConfigConsts::getColNames(false);
        $columns = array();
        $colNum = 0;
        $columns[$colNum++] = new FilterColumn(ReportingConfigConsts::colLocalTime, $colNum);
        $columns[$colNum++] = new FilterColumn(ReportingConfigConsts::colUnixTime, $colNum);
        $columns[$colNum++] = new FilterColumn(ReportingConfigConsts::colUtcUnixTime, $colNum);
        foreach($cols as $name => $value) {
            if($name != ReportingConfigConsts::colLocalTime) {
                $columns[$colNum++] = new FilterColumn($name, $colNum);
            }
        }
        return $columns;
    }
    
    public function writeConfig() {
        $doc = new DOMDocument("1.0", "utf-8");
        $doc->formatOutput = true;
        $config = $doc->appendChild($doc->createElement("config"));
        
        // write replication config
        $repl = $config->appendChild($doc->createElement("replication"));
        $repl->appendChild($doc->createElement("mode", xmlentities($this->replication->mode)));
        $repl->appendChild($doc->createElement("server", xmlentities($this->replication->server)));
        $repl->appendChild($doc->createElement("password", xmlentities( rc4_encrypt(strrev($this->replication->server), $this->replication->password))));
        $repl->appendChild($doc->createElement("interval", xmlentities((string)$this->replication->interval)));

        $pbx = $config->appendChild($doc->createElement("pbx"));
        $pbx->appendChild($doc->createElement("identifier", xmlentities($this->pbx->identifier)));
        
        $cleanup = $config->appendChild($doc->createElement("cleanup"));
        $cleanup->setAttribute("active", $this->cleanup->active ? "1" : "0");
        $cleanup->setAttribute("months", $this->cleanup->months);
        $cleanup->setAttribute("weeks", $this->cleanup->weeks);
        
        $voicePlayer = $config->appendChild($doc->createElement("voice-player"));
        $voicePlayer->appendChild($doc->createElement("port", $this->voicePlayer->port));
        // save doc
        if($doc->save(Config::reportingConfig) === false) {
            $this->error = tl::tlx('Couldn\'t rewrite reporting config \'{$arg[1]}\'.', Config::reportingConfig);
            return false;
        }
    }
    
    public function write() {
        if($this->writeConfig() === false) {
            return false;
        }
        
        global $reportingSession;
        $reportingSession->updateReportingCfg($this);
        return true;
    }
}

class ReportingUser {
    var $id = 0;
    var $password = "";
    var $name = "";
    var $filters = array(); // the template filters the user is allowed to use
}

class ReportingSession {
    /**
     *
     * @var Filter
     */
    var $filter = null;
    /**
     *
     * @var ReportMail
     */
    var $reportMail = null;
    /**
     *
     * @var ReportingXmlCfg
     */
    var $reportingCfg = null;
    /**
     *
     * @var LdapServer
     */
    var $ldapServer = null;
    /**
     *
     * @var MainSession
     */
    var $mainSession;
    
    var $userCookie = null; 
    var $passwordCookie = null;
    var $sessionLoggedIn = false;
    /**
     * @var ReportingUser 
     *
     */    
    var $user = null;       // a logged in user
    
    
    public function ReportingSession() {
        global $mainSession;
        $this->mainSession = $mainSession;
        $this->filter = new Filter();
        $this->reportMail = new ReportMail();
        $this->ldapServer = new LdapServer();
        $this->user = new ReportingUser();
        
        if($this->mainSession->restore($this->filter, "filter", false) === false) {
            $this->mainSession->save($this->filter, "filter");
            $this->mainSession->save($this->reportMail, "reportmail");
            $this->mainSession->save($this->ldapServer, "ldapserver");
            $this->reportingCfg = new ReportingXmlCfg();
            $this->mainSession->save($this->reportingCfg, "reportingcfg");
            $this->mainSession->save($this->user, "reportinguser");
            $this->mainSession->save($this->sessionLoggedIn, "loggedin");
        }
        $this->mainSession->restore($this->reportingCfg, "reportingcfg");
        $this->mainSession->restore($this->filter, "filter");
        $this->mainSession->restore($this->reportMail, "reportmail");
        $this->mainSession->restore($this->ldapServer, "ldapserver");
        $this->mainSession->restore($this->user, "reportinguser");
        $this->mainSession->restore($this->sessionLoggedIn, "loggedin");
        $ip = get_dhcp_address();
        $this->userCookie = new innoCookie("innoreportinguser", innoCookie::NEVER, $ip);
        $this->passwordCookie = new innoCookie("innoreportingpw", innoCookie::NEVER, $ip);
        $this->checkReportingCfg();
    }
    
    function isUser() {
        if($this->user->id > 0 && ReportingMethods::isUserPath()) {
            return true;
        }
        return false;
    }
    
    function checkReportingCfg() {
        if(file_exists(Config::reportingConfig)) {
            $mtime = filemtime(Config::reportingConfig);
            if($this->reportingCfg == null || $mtime != $this->reportingCfg->mtime) {
                $this->updateReportingCfg(new ReportingXmlCfg());
            }
        }
    }
    
    function updateReportingCfg($cfg) {
        $this->reportingCfg = $cfg;
        $this->mainSession->save($this->reportingCfg, "reportingcfg");
    }
    
    function updateFilter($filter) {
        $this->filter = $filter;
        $this->mainSession->save($this->filter, "filter");
    }
    
    function updateReportMail($reportMail) {
        $this->reportMail = $reportMail;
        $this->mainSession->save($this->reportMail, "reportmail");
    }
    
    function updateLdapServer($ldapServer) {
        $this->ldapServer = $ldapServer;
        $this->mainSession->save($this->ldapServer, "ldapserver");
    }
    
    function updateUser($user) {
        $this->user = $user;
        $this->mainSession->save($this->user, "reportinguser");
    }
    
    function cmp_order($a, $b) {
        if ($a->sortOrder == $b->sortOrder) return 0;
        return ($a->sortOrder < $b->sortOrder)? -1 : 1; 
    } 
    
    function getColumns($filters, $cols) {
        $maxNumCols = 0;
        $numFilters = count($filters);
        foreach($filters as $filter) {
            $maxNumCols = max($maxNumCols, count($filter->columns));
        }
        foreach($filters as $filter) {
            foreach($filter->columns as $col) {
                if(!isset($cols[$col->name])) {
                    $cols[$col->name] = $col;
                    $cols[$col->name]->sortOrder = (!$col->sortOrder) ? $maxNumCols : $col->sortOrder;
                    $cols[$col->name]->numDefs = 1;
                }
                else {
                    $cols[$col->name]->sortOrder += (!$col->sortOrder) ? $maxNumCols : $col->sortOrder;
                    $cols[$col->name]->numDefs++;
                }
            }
        }
        /* in case some column is not defined in all selected filter */
        foreach($cols as $col) {
            if($col->numDefs < $numFilters) {
                $col->sortOrder += (($numFilters - $col->numDefs)*$maxNumCols);
            }
        }
        uasort($cols, array("ReportingSession", "cmp_order"));
        return $cols;
    }   
}

class LoginCheck extends Login {
    public function LoginCheck(mySession &$session, innoCookie &$userCookie, innoCookie &$passwordCookie) {
        $this->Login($session, $userCookie, $passwordCookie);
    }
    
    public function checkLogin(InputPage &$page) {
    }
    
    public function checkLogin2() {
        $loginpage = stripos($_SERVER['SCRIPT_FILENAME'], "login.php");
        global $reportingSession;
        if($this->sessionexist === true) {
            if($reportingSession->user->id === 0) {
                LoginCheck::destroy();
                header("location: login.php");
                exit;
            }
            if($loginpage !== false) {
                header("location: report.php");
                exit;
            }
            return;
        }
        if(!$this->user || !$this->password) {
            if($loginpage === false) {
                header("location: login.php");
                exit;
            }
        }
        else {
            $result = ReportingMethods::checkAccount($this->user, $this->password);
            $row = pg_fetch_object($result);
            if(!$row) {
                if($loginpage === false) {
                    header("location: login.php");
                    exit;
                }   
            }
            else {
                // set session status login!
                $reportingSession->sessionLoggedIn = true;
                $reportingSession->mainSession->save($reportingSession->sessionLoggedIn, "loggedin");
                $reportingSession->updateUser(ReportingMethods::getUserFromRow($row));
                if($loginpage !== false) {
                    header("location: report.php");
                    exit;
                }
            }
        }
    }
    
    static function destroy() {
        global $reportingSession;
        if($reportingSession->userCookie->value != "") {
            $reportingDb = get_reporting_db();
            $query = "UPDATE users SET cookie='' WHERE name='{$reportingSession->userCookie->value}'";
            $reportingDb->run($query);
        }
        $reportingSession->mainSession->destroy();
        $reportingSession->userCookie->clear();
        $reportingSession->passwordCookie->clear(); 
    }
    
    static function updateCookies($name, $id) {
        global $reportingSession;
        $uniqueCookie = uniqid($id, true);
        $reportingSession->passwordCookie->set($uniqueCookie);
        $reportingSession->userCookie->set($name);
        $reportingDb = get_reporting_db();
        $query = "UPDATE users SET cookie='$uniqueCookie' WHERE id=$id";
        $reportingDb->run($query);
    }
}

$reportingSession = new ReportingSession();
if($reportingSession->mainSession->error) {
    $reportingSession->mainSession->destroy();
    home_die($reportingSession->mainSession->error, "report.php");
}

if(ReportingMethods::isUserPath()) {
    $loginCheck = new LoginCheck($reportingSession->mainSession, $reportingSession->userCookie, $reportingSession->passwordCookie);
    $loginCheck->checkLogin2();
}
?>
